function [g1]=diezmado_media_ponderadac(g0)
%Process obtained from: 
% Adelson, P. L. (1983). The Laplacian pyramid as a compact image code. 

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Reduce
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% With this we want to reduce the size to the image by half.
% g0 == input image
% g1 == outise image (enter image reduce by half)
% In order to calculate the value of the pixel we make the weighted average
% of the neighbors pixels (with a 5x5 mask)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % KELNER
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Here we have the kerlner (the 5x5 mask) we are going to use for doing
    % the weighted average
    a=0.2; %value in the weighted average of the central pixel (0.2<a<0.5)
    W=[((1/4)-(a/2)),(1/4),a,(1/4),((1/4)-(a/2));...
        ((1/4)-(a/2)),(1/4),a,(1/4),((1/4)-(a/2));...
        ((1/4)-(a/2)),(1/4),a,(1/4),((1/4)-(a/2));...
        ((1/4)-(a/2)),(1/4),a,(1/4),((1/4)-(a/2));...
        ((1/4)-(a/2)),(1/4),a,(1/4),((1/4)-(a/2))];

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % ZERO PADDING
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % for applying the kelner we have a problem with the borders, in order
    % to solver we make zero padding and we copy the border in those new
    % row and column 
    
    [mx,my]=size(g0);
    %Image with the new dimension
    padded = ones(mx+4,my+4);
    padded(3:mx+2,3:my+2) = g0;
    
    %Copy of the border on the black new rows and columns
    padded(1,3:my+2) = g0(1,:);
    padded(2,3:my+2) = g0(1,:);
    padded(mx+3,3:my+2) = g0(mx,:);
    padded(mx+4,3:my+2) = g0(mx,:);

    padded(:,1) = padded(:,3);
    padded(:,2) = padded(:,3);
    padded(:,my+4) = padded(:,my+2);
    padded(:,my+3) = padded(:,my+2);


    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % Reduce algorithm
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    [C,R]=size(g0);
    for x = 2:(C/2)+1

        for y = 2:(R/2)+1

        g1(x-1,y-1)=(sum(sum(W.* padded((2*x)-2:(2*x)+2, ...
            (2*y)-2:(2*y)+2))))/5;

        end
    end
end