function [imagen45,imagen135]=Filtros_gabor_duplicando_bordes(g0,f0)
%input g0 == image
%output are the image filtered with Gabor filters with orientations 45 and
%135

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% GABOR FILTERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%omega is in charge of the orientation of the filter
omega1=45*pi/180 ; %filter orientation 45*pi/180 == 45
omega3=135*pi/180 ; %filter orientation 135*pi/180 == 135

% f0=0.2 ; %frecuency of subsampling
K=1; %amplitude
tita= 0; %Rotation angle of the Gaussian envelope.

% "a" and "b" are the width (x and y axis) of the envelope
% they are put this way because we need a constant in (a logarithmic scale)
% one octave bandwidth in the frequency domain.
a=f0/(3*sqrt(log(2)/pi)); 
b=f0/(3*sqrt(log(2)/pi)); 

nx=5; %width of the filter in the x-axis
ny=5; %width of the filter in the y-axis
x0=0; %position of the gaussian in the filter x-axis
y0=0; %position of the gaussian in the filter y-axis

for x=-nx:nx
    for y=-ny:ny
        
        g45(nx+1+x,ny+1+y)=K*exp((-pi)*(((a^2)*(((x-x0)*cos(tita)+(y-y0)*...
            sin(tita)))^2)+((b^2)*((-(x-x0)*sin(tita)+(y-y0)*cos(tita)))^2)))*...
            exp(1i*(2*pi*f0*(x*cos(omega1)+y*sin(omega1))));
        
    end
end

for x=-nx:nx
    for y=-ny:ny
        
        g135(nx+1+x,ny+1+y)=K*exp((-pi)*(((a^2)*(((x-x0)*cos(tita)+(y-y0)*...
            sin(tita)))^2)+((b^2)*((-(x-x0)*sin(tita)+(y-y0)*cos(tita)))^2)))*...
            exp(1i*(2*pi*f0*(x*cos(omega3)+y*sin(omega3))));
        
    end
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% ZERO-PADDING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[mx,my]=size(g0);
padded = zeros(mx+10,my+10);
padded(6:mx+5,6:my+5) = g0;

%we copy the borders of the picture in the new blank columns and rows
padded(1,6:my+5) = g0(1,:);
padded(2,6:my+5) = g0(1,:);
padded(3,6:my+5) = g0(1,:);
padded(4,6:my+5) = g0(1,:);
padded(5,6:my+5) = g0(1,:);
padded(6,6:my+5) = g0(1,:);

padded(mx+6,6:my+5) = g0(mx,:);
padded(mx+7,6:my+5) = g0(mx,:);
padded(mx+8,6:my+5) = g0(mx,:);
padded(mx+9,6:my+5) = g0(mx,:);
padded(mx+10,6:my+5) = g0(mx,:);
padded(mx+11,6:my+5) = g0(mx,:);

padded(:,1) = padded(:,6);
padded(:,2) = padded(:,6);
padded(:,3) = padded(:,6);
padded(:,4) = padded(:,6);
padded(:,5) = padded(:,6);
padded(:,6) = padded(:,6);

padded(:,my+6) = padded(:,my+5);
padded(:,my+7) = padded(:,my+5);
padded(:,my+8) = padded(:,my+5);
padded(:,my+9) = padded(:,my+5);
padded(:,my+10) = padded(:,my+5);
padded(:,my+11) = padded(:,my+5);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% CONVOLUTION
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

imagen450=conv2(padded,imag(g45),'same');
imagen1350=conv2(padded,imag(g135),'same');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% TAKE OF ZERO-PADDING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
imagen45=imagen450(6:mx+5,6:my+5);
imagen135=imagen1350(6:mx+5,6:my+5);

end