function [g1f]=separable_cubic_B_spline_filter(g0)
%the formels come from: Pratt, W. K.  Digital Image Processing

% before reducing the image we nedd to apply a low-pass filter so we avoid
% aliasing, we must do it every time we are going to reduce the image
% g0 == input image
% g1f == filteres image

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%SEPARABLE CUBIC B - SPLINE FILTER
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Here we are going to make the filter we are going to use
% lets call '**' convolution
% the cubic B-spline filter is R3(x,y)
% R3(x,y)=R0(x,y)**R1(x,y) while R1(x,y)=R0(x,y)**R0(x,y) 
% R0= (1/(Tx*Ty)) if |x| <= Tx/2 y |y| <= Ty/2
% R0= 0 for the res
% The filter must have at least 5 elements

ny= 5; %Dimensios of the filter (will have double of that)
nx= 5; %Dimensios of the filter (will have double of that)
Tx= 2 ; %width of square x axi(final width will be Tx+1 because of 0 value)
Ty= 2 ; %width of square y axi(final width will be Tx+1 because of 0 value)

%R0 o separable square
for x=-nx:nx
    for y=-ny:ny
        
         if ((abs(x)<(Tx/2) || abs(x)==(Tx/2)) && ...
               (abs(y)<(Ty/2) || abs(y)==(Tx/2)))
            
            R0(nx+1+x,ny+1+y)= 1/(Tx*Ty);
            
        else R0(nx+1+x,ny+1+y)=0;
        end
    end
end

%R1 o separable triangle
R1=conv2(R0,R0,'same');
%R2 o Separable Bell
R2=conv2(R1,R0,'same');
%R3 o Separable cubic B - spline filter
R3=conv2(R2,R0,'same');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%ZERO-PADDING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
[mx,my]=size(g0);
padded = zeros(mx+12,my+12);
padded(7:mx+6,7:my+6) = g0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%FILTER OF THE IMAGE
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
g1f=conv2(padded,R3,'same');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%TAKE OFF-ZERO PADDING
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
g1f=g1f(7:mx+6,7:my+6);

end